/********************************************************************************
** Form generated from reading UI file 'sweeperdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SWEEPERDIALOG_H
#define UI_SWEEPERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_SweeperDialog
{
public:
    QVBoxLayout *vboxLayout;
    QSplitter *splitter1;
    QTreeWidget *privacyListView;
    KTextEdit *statusTextEdit;
    QHBoxLayout *hboxLayout;
    QPushButton *selectAllButton;
    QPushButton *selectNoneButton;
    QSpacerItem *spacerItem;
    QPushButton *cleanupButton;

    void setupUi(QWidget *SweeperDialog)
    {
        if (SweeperDialog->objectName().isEmpty())
            SweeperDialog->setObjectName("SweeperDialog");
        SweeperDialog->resize(600, 480);
        vboxLayout = new QVBoxLayout(SweeperDialog);
        vboxLayout->setObjectName("vboxLayout");
        splitter1 = new QSplitter(SweeperDialog);
        splitter1->setObjectName("splitter1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(splitter1->sizePolicy().hasHeightForWidth());
        splitter1->setSizePolicy(sizePolicy);
        splitter1->setOrientation(Qt::Vertical);
        privacyListView = new QTreeWidget(splitter1);
        privacyListView->setObjectName("privacyListView");
        privacyListView->setAlternatingRowColors(true);
        privacyListView->setProperty("itemsMovable", QVariant(false));
        splitter1->addWidget(privacyListView);
        statusTextEdit = new KTextEdit(splitter1);
        statusTextEdit->setObjectName("statusTextEdit");
        statusTextEdit->setReadOnly(true);
        splitter1->addWidget(statusTextEdit);

        vboxLayout->addWidget(splitter1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        selectAllButton = new QPushButton(SweeperDialog);
        selectAllButton->setObjectName("selectAllButton");

        hboxLayout->addWidget(selectAllButton);

        selectNoneButton = new QPushButton(SweeperDialog);
        selectNoneButton->setObjectName("selectNoneButton");

        hboxLayout->addWidget(selectNoneButton);

        spacerItem = new QSpacerItem(171, 16, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        cleanupButton = new QPushButton(SweeperDialog);
        cleanupButton->setObjectName("cleanupButton");

        hboxLayout->addWidget(cleanupButton);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(SweeperDialog);

        QMetaObject::connectSlotsByName(SweeperDialog);
    } // setupUi

    void retranslateUi(QWidget *SweeperDialog)
    {
        QTreeWidgetItem *___qtreewidgetitem = privacyListView->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Description", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Privacy Settings", nullptr));
#if QT_CONFIG(whatsthis)
        privacyListView->setWhatsThis(tr2i18n("Check all cleanup actions you would like to perform. These will be executed by pressing the button below.", nullptr));
#endif // QT_CONFIG(whatsthis)
        selectAllButton->setText(tr2i18n("Select &All", nullptr));
        selectNoneButton->setText(tr2i18n("Select &None", nullptr));
#if QT_CONFIG(whatsthis)
        cleanupButton->setWhatsThis(tr2i18n("Immediately performs the cleanup actions selected above", nullptr));
#endif // QT_CONFIG(whatsthis)
        cleanupButton->setText(tr2i18n("&Clean Up", nullptr));
        (void)SweeperDialog;
    } // retranslateUi

};

namespace Ui {
    class SweeperDialog: public Ui_SweeperDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SWEEPERDIALOG_H

